//
// Parago Media GmbH & Co. KG, Jrgen Burle (jbaurle@parago.de)
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
// TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
// CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
// DEALINGS IN THE SOFTWARE.
//

using System;
using System.IO;
using Parago.DALComp.Compiler;

namespace Parago.DALComp {

	class Program {

		/// <summary>
		/// Start of console application that will read in a sample DAL source 
		/// file, parse it, generate either C# or VB source code and finally
		/// write the new generated code to a text file.
		/// </summary>
		static void Main(string[] args) {

			// Read source code to compile from file Sample.dal
			string source=String.Empty;
			using(StreamReader reader=new StreamReader(@"Data\Sample.dal")) {
				source=reader.ReadToEnd();
				reader.Close();
			}

			// Tokenize, parse and generate DAL code and output
			// the final generated C# source code
			Tokenizer tokenizer=new Tokenizer(source);
			Parser parser=new Parser(tokenizer);
			CodeGen codeGen=new CodeGen(parser);

			// Write generated C# source code to file
			Console.Write("Generate source code for C#... ");
			using(StreamWriter writer=new StreamWriter(@"Data\Sample.dal.cs")) {
				writer.WriteLine(codeGen.GenerateSourceCodeCSharp());
				writer.Close();
			}
			Console.WriteLine("Ok");

			// Write generated VB.NET source code to file
			Console.Write("Generate source code for VB... ");
			using(StreamWriter writer=new StreamWriter(@"Data\Sample.dal.vb")) {
				writer.WriteLine(codeGen.GenerateSourceCodeVB());
				writer.Close();
			}
			Console.WriteLine("Ok");

		}

	}

}
